@@ -79,6 +79,7 @@ import com.openexchange.java.Strings;
 import com.openexchange.publish.Publication;
 import com.openexchange.publish.PublicationErrorMessage;
 import com.openexchange.publish.tools.PublicationSession;
+import com.openexchange.server.ServiceExceptionCode;
 import com.openexchange.session.Session;
 import com.openexchange.tools.session.ServerSession;
 import com.openexchange.tools.session.ServerSessionAdapter;
@@ -150,20 +151,27 @@ public class InfostoreFileServlet extends OnlinePublicationServlet {
             startedWriting = true;
             writeFile(new PublicationSession(publication), metadata, fileData, req, resp);
 
-        } catch (final Throwable t) {
+        } catch (Exception e) {
             resp.setStatus(HttpServletResponse.SC_INTERNAL_SERVER_ERROR);
             if(!startedWriting) {
-                t.printStackTrace(resp.getWriter());
+                e.printStackTrace(resp.getWriter());
             }
-            LOG.error("", t);
+            LOG.error("", e);
         }
 
     }
 
     protected DocumentMetadata loadMetadata(final Publication publication, final int infoId) throws OXException {
         try {
+            IDBasedFileAccessFactory factory = fileFactory;
+            if (null == factory) {
+                throw ServiceExceptionCode.absentService(IDBasedFileAccessFactory.class);
+            }
+            if (publication == null) {
+                throw PublicationErrorMessage.NOT_FOUND_EXCEPTION.create();
+            }
             Session session = new PublicationSession(publication);
-            IDBasedFileAccess fileAccess = fileFactory.createAccess(session);
+            IDBasedFileAccess fileAccess = factory.createAccess(session);
             String id = publication.getEntityId() + '/' + infoId;
             return FileMetadata.getMetadata(fileAccess.getFileMetadata(id, FileStorageFileAccess.CURRENT_VERSION));
         } catch (final OXException e) {
@@ -176,7 +184,7 @@ public class InfostoreFileServlet extends OnlinePublicationServlet {
 
     private void writeFile(final Session session, final DocumentMetadata metadata, final InputStream fileData, final HttpServletRequest req, final HttpServletResponse resp) throws IOException, OXException {
         final FileResponseRenderer renderer = fileResponseRenderer;
-        if (null == fileResponseRenderer) {
+        if (null == renderer) {
             throw new IOException("Missing " + FileResponseRenderer.class.getName());
         }
         final ServerSession serverSession = ServerSessionAdapter.valueOf(session);
